summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorINADA Naoki <inada-n@klab.com>2012-09-23 10:00:18 +0900
committerINADA Naoki <inada-n@klab.com>2012-09-23 10:00:18 +0900
commiteaf9891b4255f3b1ca5cf2ea5b631091523b913d (patch)
tree9e78da7c729e316860b773e96ef2c743c5c1a134
parent65f582345c468b3c803b1e0100181bf9bde7f290 (diff)
downloadmsgpack-python-eaf9891b4255f3b1ca5cf2ea5b631091523b913d.tar.gz
clean some cython code.
-rw-r--r--msgpack/_msgpack.pyx28
-rw-r--r--msgpack/unpack_template.h2
2 files changed, 16 insertions, 14 deletions
diff --git a/msgpack/unpack_template.h b/msgpack/unpack_template.h
index 10e41e1..5495a51 100644
--- a/msgpack/unpack_template.h
+++ b/msgpack/unpack_template.h
@@ -95,7 +95,7 @@ msgpack_unpack_func(msgpack_unpack_object, _data)(msgpack_unpack_struct(_context
}
-msgpack_unpack_func(int, _execute)(msgpack_unpack_struct(_context)* ctx, const char* data, size_t len, size_t* off, bool construct)
+msgpack_unpack_func(int, _execute)(msgpack_unpack_struct(_context)* ctx, const char* data, size_t len, size_t* off, int construct)
{
assert(len >= *off);
diff --git a/msgpack/_msgpack.pyx b/msgpack/_msgpack.pyx
index 9061d42..c8ee7bb 100644
--- a/msgpack/_msgpack.pyx
+++ b/msgpack/_msgpack.pyx
@@ -209,7 +209,7 @@ cdef extern from "unpack.h":
PyObject* key
int template_execute(template_context* ctx, const_char_ptr data,
size_t len, size_t* off, bool construct) except -1
void template_init(template_context* ctx)
object template_data(template_context* ctx)
@@ -255,7 +255,7 @@ def unpackb(object packed, object object_hook=None, object list_hook=None,
if not PyCallable_Check(list_hook):
raise TypeError("list_hook must be a callable.")
ctx.user.list_hook = <PyObject*>list_hook
- ret = template_execute(&ctx, buf, buf_len, &off, True)
+ ret = template_execute(&ctx, buf, buf_len, &off, 1)
if ret == 1:
obj = template_data(&ctx)
if off < buf_len:
@@ -451,12 +451,18 @@ cdef class Unpacker(object):
else:
self.file_like = None
- cpdef _unpack(self, bool construct):
+ cdef _unpack(self, bint construct):
cdef int ret
+ cdef object obj
while 1:
ret = template_execute(&self.ctx, self.buf, self.buf_tail, &self.buf_head, construct)
if ret == 1:
- return
+ if construct:
+ obj = template_data(&self.ctx)
+ else:
+ obj = None
+ template_init(&self.ctx)
+ return obj
elif ret == 0:
if self.file_like is not None:
self.read_from_file()
@@ -465,23 +471,19 @@ cdef class Unpacker(object):
else:
raise ValueError("Unpack failed: error = %d" % (ret,))
- cpdef unpack(self):
+ def unpack(self):
"""unpack one object"""
- self._unpack(True)
- o = template_data(&self.ctx)
- template_init(&self.ctx)
-
+ return self._unpack(1)
- cpdef skip(self):
+ def skip(self):
"""read and ignore one object, returning None"""
- self._unpack(False)
- template_init(&self.ctx)
+ return self._unpack(0)
def __iter__(self):
return self
def __next__(self):
- return self.unpack()
+ return self._unpack(1)
# for debug.
#def _buf(self):
@@ -209,7 +209,7 @@ cdef extern from "unpack.h":
PyObject* key
int template_execute(template_context* ctx, const_char_ptr data,
- size_t len, size_t* off, bool construct) except -1
+ size_t len, size_t* off, bint construct) except -1
void template_init(template_context* ctx)
object template_data(template_context* ctx)